@@ -1,20 +1,8 @@
-/* This file is part of the KDE libraries
-   Copyright (C) 2010 Bernhard Beschow <bbeschow@cs.tu-berlin.de>
+/*
+    This file is part of the KDE libraries
+    SPDX-FileCopyrightText: 2010 Bernhard Beschow <bbeschow@cs.tu-berlin.de>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "searchbar_test.h"
@@ -93,6 +81,37 @@ void SearchBarTest::testFindNextIncremental()
     QCOMPARE(view.selectionRange(), Range(0, 0, 0, 1));
 }
 
+
+void SearchBarTest::testFindNextZeroLengthMatch()
+{
+    // Some regularexpression matches are zero length assertions
+    // e.g. '$', '^', '\b', test that the cursor won't be stuck
+    // on one match when using FindNext
+    KTextEditor::DocumentPrivate doc;
+    doc.setText("a\nb \nc\n\n");
+
+    KTextEditor::ViewPrivate view(&doc, nullptr);
+    KateViewConfig config(&view);
+    KateSearchBar bar(true, &view, &config);
+    bar.setSearchMode(KateSearchBar::MODE_REGEX);
+
+    bar.setSearchPattern("$");
+
+    QVERIFY(bar.isPower());
+
+    bar.findNext();
+    QCOMPARE(view.cursorPosition(), Cursor(0,1));
+
+    bar.findNext();
+    QCOMPARE(view.cursorPosition(), Cursor(1,2));
+
+    bar.findNext();
+    QCOMPARE(view.cursorPosition(), Cursor(2,1));
+
+    bar.findNext();
+    QCOMPARE(view.cursorPosition(), Cursor(3,0));
+}
+
 void SearchBarTest::testSetMatchCaseIncremental()
 {
     KTextEditor::DocumentPrivate doc;
@@ -513,12 +532,10 @@ void SearchBarTest::testReplaceDollar()
 
     KateSearchBar bar(true, &view, &config);
 
-    bar.setSearchPattern("$");
+    bar.setSearchPattern(QStringLiteral("$"));
     bar.setSearchMode(KateSearchBar::MODE_REGEX);
     bar.setReplacementPattern("D");
-
     bar.replaceAll();
-
     QCOMPARE(doc.text(), QString("aaaD\nbbbD\ncccD\nD\nD\naaaD\nbbbD\ncccD\ndddD\n"));
 }
 
