@@ -1,54 +1,46 @@
-/*  This file is part of the Kate project.
- *
- *  Copyright (C) 2010 Christoph Cullmann <cullmann@kde.org>
- *
- *  This library is free software; you can redistribute it and/or
- *  modify it under the terms of the GNU Library General Public
- *  License as published by the Free Software Foundation; either
- *  version 2 of the License, or (at your option) any later version.
- *
- *  This library is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- *  Library General Public License for more details.
- *
- *  You should have received a copy of the GNU Library General Public License
- *  along with this library; see the file COPYING.LIB.  If not, write to
- *  the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- *  Boston, MA 02110-1301, USA.
- */
+/*
+    SPDX-FileCopyrightText: 2010 Christoph Cullmann <cullmann@kde.org>
+
+    SPDX-License-Identifier: LGPL-2.0-or-later
+*/
 
 #include "config.h"
 #include "kateglobal.h"
 
-#include "katetextbuffer.h"
 #include "katesecuretextbuffer_p.h"
+#include "katetextbuffer.h"
 #include "katetextloader.h"
 
 // this is unfortunate, but needed for performance
 #include "katedocument.h"
-#include "kateview.h"
 #include "katepartdebug.h"
+#include "kateview.h"
 
 #ifndef Q_OS_WIN
+#include <errno.h>
 #include <unistd.h>
+// sadly there seems to be no possibility in Qt to determine detailed error
+// codes about e.g. file open errors, so we need to resort to evaluating
+// errno directly on platforms that support this
+#define CAN_USE_ERRNO
 #endif
 
-#include <QFile>
-#include <QTemporaryFile>
-#include <QFileInfo>
-#include <QCryptographicHash>
 #include <QBuffer>
+#include <QCryptographicHash>
+#include <QFile>
+#include <QFileInfo>
+#include <QTemporaryFile>
 
 #if 0
 #define BUFFER_DEBUG qCDebug(LOG_KTE)
 #else
-#define BUFFER_DEBUG if (0) qCDebug(LOG_KTE)
+#define BUFFER_DEBUG                                                                                                                                                                                                                           \
+    if (0)                                                                                                                                                                                                                                     \
+    qCDebug(LOG_KTE)
 #endif
 
 namespace Kate
 {
-
 TextBuffer::TextBuffer(KTextEditor::DocumentPrivate *parent, int blockSize, bool alwaysUseKAuth)
     : QObject(parent)
     , m_document(parent)
@@ -92,7 +84,7 @@ TextBuffer::~TextBuffer()
     Q_ASSERT(m_ranges.empty());
 
     // clean out all cursors and lines, only cursors belonging to range will survive
-    foreach (TextBlock *block, m_blocks) {
+    for (TextBlock *block : qAsConst(m_blocks)) {
         block->deleteBlockContent();
     }
 
@@ -110,8 +102,8 @@ TextBuffer::~TextBuffer()
 void TextBuffer::invalidateRanges()
 {
     // invalidate all ranges, work on copy, they might delete themself...
-    QSet<TextRange *> copyRanges = m_ranges;
-    foreach (TextRange *range, copyRanges) {
+    const QSet<TextRange *> copyRanges = m_ranges;
+    for (TextRange *range : copyRanges) {
         range->setRange(KTextEditor::Cursor::invalid(), KTextEditor::Cursor::invalid());
     }
 }
@@ -128,7 +120,7 @@ void TextBuffer::clear()
     newBlock->appendLine(QString());
 
     // clean out all cursors and lines, either move them to newBlock or invalidate them, if belonging to a range
-    foreach (TextBlock *block, m_blocks) {
+    for (TextBlock *block : qAsConst(m_blocks)) {
         block->clearBlockContent(newBlock);
     }
 
@@ -173,7 +165,7 @@ QString TextBuffer::text() const
     QString text;
 
     // combine all blocks
-    foreach (TextBlock *block, m_blocks) {
+    for (TextBlock *block : qAsConst(m_blocks)) {
         block->text(text);
     }
 
@@ -245,12 +237,10 @@ void TextBuffer::wrapLine(const KTextEditor::Cursor &position)
     // get block, this will assert on invalid line
     int blockIndex = blockForLine(position.line());
 
-    /**
-     * let the block handle the wrapLine
-     * this can only lead to one more line in this block
-     * no other blocks will change
-     * this call will trigger fixStartLines
-     */
+    // let the block handle the wrapLine
+    // this can only lead to one more line in this block
+    // no other blocks will change
+    // this call will trigger fixStartLines
     ++m_lines; // first alter the line counter, as functions called will need the valid one
     m_blocks.at(blockIndex)->wrapLine(position, blockIndex);
 
@@ -294,12 +284,10 @@ void TextBuffer::unwrapLine(int line)
     // is this the first line in the block?
     bool firstLineInBlock = (line == m_blocks.at(blockIndex)->startLine());
 
-    /**
-     * let the block handle the unwrapLine
-     * this can either lead to one line less in this block or the previous one
-     * the previous one could even end up with zero lines
-     * this call will trigger fixStartLines
-     */
+    // let the block handle the unwrapLine
+    // this can either lead to one line less in this block or the previous one
+    // the previous one could even end up with zero lines
+    // this call will trigger fixStartLines
     m_blocks.at(blockIndex)->unwrapLine(line, (blockIndex > 0) ? m_blocks.at(blockIndex - 1) : nullptr, firstLineInBlock ? (blockIndex - 1) : blockIndex);
     --m_lines;
 
@@ -424,14 +412,10 @@ int TextBuffer::blockForLine(int line) const
     Q_ASSERT(!m_blocks.isEmpty());
     Q_ASSERT(m_lastUsedBlock >= 0);
 
-    /**
-     * shortcut: try last block first
-     */
+    // shortcut: try last block first
     if (m_lastUsedBlock < m_blocks.size()) {
-        /**
-         * check if block matches
-         * if yes, just return again this block
-         */
+        // check if block matches
+        // if yes, just return again this block
         TextBlock *block = m_blocks[m_lastUsedBlock];
         const int start = block->startLine();
         const int lines = block->lines();
@@ -440,11 +424,9 @@ int TextBuffer::blockForLine(int line) const
         }
     }
 
-    /**
-     * search for right block
-     * use binary search
-     * if we leave this loop not by returning the found element we have an error
-     */
+    // search for right block
+    // use binary search
+    // if we leave this loop not by returning the found element we have an error
     int blockStart = 0;
     int blockEnd = m_blocks.size() - 1;
     while (blockEnd >= blockStart) {
@@ -500,9 +482,7 @@ void TextBuffer::fixStartLines(int startBlock)
 
 void TextBuffer::balanceBlock(int index)
 {
-    /**
-     * two cases, too big or too small block
-     */
+    // two cases, too big or too small block
     TextBlock *blockToBalance = m_blocks.at(index);
 
     // first case, too big one, split it
@@ -562,27 +542,19 @@ bool TextBuffer::load(const QString &filename, bool &encodingErrors, bool &tooLo
     // codec must be set!
     Q_ASSERT(m_textCodec);
 
-    /**
-     * first: clear buffer in any case!
-     */
+    // first: clear buffer in any case!
     clear();
 
-    /**
-     * construct the file loader for the given file, with correct prober type
-     */
+    // construct the file loader for the given file, with correct prober type
     Kate::TextLoader file(filename, m_encodingProberType);
 
-    /**
-     * triple play, maximal three loading rounds
-     * 0) use the given encoding, be done, if no encoding errors happen
-     * 1) use BOM to decided if Unicode or if that fails, use encoding prober, if no encoding errors happen, be done
-     * 2) use fallback encoding, be done, if no encoding errors happen
-     * 3) use again given encoding, be done in any case
-     */
-    for (int i = 0; i < (enforceTextCodec ? 1 : 4);  ++i) {
-        /**
-         * kill all blocks beside first one
-         */
+    // triple play, maximal three loading rounds
+    // 0) use the given encoding, be done, if no encoding errors happen
+    // 1) use BOM to decided if Unicode or if that fails, use encoding prober, if no encoding errors happen, be done
+    // 2) use fallback encoding, be done, if no encoding errors happen
+    // 3) use again given encoding, be done in any case
+    for (int i = 0; i < (enforceTextCodec ? 1 : 4); ++i) {
+        // kill all blocks beside first one
         for (int b = 1; b < m_blocks.size(); ++b) {
             TextBlock *block = m_blocks.at(b);
             block->clearLines();
@@ -590,18 +562,14 @@ bool TextBuffer::load(const QString &filename, bool &encodingErrors, bool &tooLo
         }
         m_blocks.resize(1);
 
-        /**
-         * remove lines in first block
-         */
+        // remove lines in first block
         m_blocks.last()->clearLines();
         m_lines = 0;
 
-        /**
-         * try to open file, with given encoding
-         * in round 0 + 3 use the given encoding from user
-         * in round 1 use 0, to trigger detection
-         * in round 2 use fallback
-         */
+        // try to open file, with given encoding
+        // in round 0 + 3 use the given encoding from user
+        // in round 1 use 0, to trigger detection
+        // in round 2 use fallback
         QTextCodec *codec = m_textCodec;
         if (i == 1) {
             codec = nullptr;
@@ -633,62 +601,44 @@ bool TextBuffer::load(const QString &filename, bool &encodingErrors, bool &tooLo
             // get Unicode data for this line
             const QChar *unicodeData = file.unicode() + offset;
 
+            if (longestLineLoaded < length)
+                longestLineLoaded = length;
 
-            if (longestLineLoaded < length) longestLineLoaded=length;
-
-            /**
-             * split lines, if too large
-             */
+            // split lines, if too large
             do {
-                /**
-                 * calculate line length
-                 */
+                // calculate line length
                 int lineLength = length;
                 if ((m_lineLengthLimit > 0) && (lineLength > m_lineLengthLimit)) {
-                    /**
-                     * search for place to wrap
-                     */
+                    // search for place to wrap
                     int spacePosition = m_lineLengthLimit - 1;
                     for (int testPosition = m_lineLengthLimit - 1; (testPosition >= 0) && (testPosition >= (m_lineLengthLimit - (m_lineLengthLimit / 10))); --testPosition) {
-                        /**
-                         * wrap place found?
-                         */
+                        // wrap place found?
                         if (unicodeData[testPosition].isSpace() || unicodeData[testPosition].isPunct()) {
                             spacePosition = testPosition;
                             break;
                         }
                     }
 
-                    /**
-                     * wrap the line
-                     */
+                    // wrap the line
                     lineLength = spacePosition + 1;
                     length -= lineLength;
                     tooLongLinesWrapped = true;
                 } else {
-                    /**
-                     * be done after this round
-                     */
+                    // be done after this round
                     length = 0;
                 }
 
-                /**
-                 * construct new text line with content from file
-                 * move data pointer
-                 */
+                // construct new text line with content from file
+                // move data pointer
                 QString textLine(unicodeData, lineLength);
                 unicodeData += lineLength;
 
-                /**
-                 * ensure blocks aren't too large
-                 */
+                // ensure blocks aren't too large
                 if (m_blocks.last()->lines() >= m_blockSize) {
                     m_blocks.append(new TextBlock(this, m_blocks.last()->startLine() + m_blocks.last()->lines()));
                 }
 
-                /**
-                 * append line to last block
-                 */
+                // append line to last block
                 m_blocks.last()->appendLine(textLine);
                 ++m_lines;
             } while (length > 0);
@@ -763,54 +713,36 @@ void TextBuffer::setTextCodec(QTextCodec *codec)
 
 bool TextBuffer::save(const QString &filename)
 {
-    /**
-     * codec must be set, else below we fail!
-     */
+    // codec must be set, else below we fail!
     Q_ASSERT(m_textCodec);
 
-    /**
-     * construct correct filter device
-     * we try to use the same compression as for opening
-     */
-    const KCompressionDevice::CompressionType type = KFilterDev::compressionTypeForMimeType(m_mimeTypeForFilterDev);
-    QScopedPointer<KCompressionDevice> saveFile(new KCompressionDevice(filename, type));
+    SaveResult saveRes = saveBufferUnprivileged(filename);
 
-    /**
-     * if we want to use kauth anyways or we can open the file write only => use temporary file and try to use authhelper
-     */
-    uint ownerId = -2;
-    uint groupId = -2;
-    QScopedPointer<QIODevice> temporaryBuffer;
-    if (m_alwaysUseKAuthForSave || !saveFile->open(QIODevice::WriteOnly)) {
-        /**
-         * Memorize owner and group.
-         */
-        const QFileInfo fileInfo(filename);
-        if (fileInfo.exists()) {
-            ownerId = fileInfo.ownerId();
-            groupId = fileInfo.groupId();
-        }
-
-        // if that fails we need more privileges to save this file
-        // -> we write to a temporary file and then send its path to KAuth action for privileged save
-        temporaryBuffer.reset(new QBuffer());
-
-        // open buffer for write and read (read is used for checksum computing and writing to temporary file)
-        if (!temporaryBuffer->open(QIODevice::ReadWrite)) {
-            return false;
-        }
-
-        // we are now saving to a temporary buffer with potential compression proxy
-        saveFile.reset(new KCompressionDevice(temporaryBuffer.data(), false, type));
-        if (!saveFile->open(QIODevice::WriteOnly)) {
+    if (saveRes == SaveResult::Failed) {
+        return false;
+    } else if (saveRes == SaveResult::MissingPermissions) {
+        // either unit-test mode or we're missing permissions to write to the
+        // file => use temporary file and try to use authhelper
+        if (!saveBufferEscalated(filename)) {
             return false;
         }
     }
 
-    /**
-     * construct stream + disable Unicode headers
-     */
-    QTextStream stream(saveFile.data());
+    // remember this revision as last saved
+    m_history.setLastSavedRevision();
+
+    // inform that we have saved the state
+    markModifiedLinesAsSaved();
+
+    // emit that file was saved and be done
+    emit saved(filename);
+    return true;
+}
+
+bool TextBuffer::saveBuffer(const QString &filename, KCompressionDevice &saveFile)
+{
+    // construct stream + disable Unicode headers
+    QTextStream stream(&saveFile);
     stream.setCodec(QTextCodec::codecForName("UTF-16"));
 
     // set the correct codec
@@ -862,95 +794,145 @@ bool TextBuffer::save(const QString &filename)
     }
 
     // close the file, we might want to read from underlying buffer below
-    saveFile->close();
+    saveFile.close();
 
     // did save work?
-    if (saveFile->error() != QFileDevice::NoError) {
-        BUFFER_DEBUG << "Saving file " << filename << "failed with error" << saveFile->errorString();
+    if (saveFile.error() != QFileDevice::NoError) {
+        BUFFER_DEBUG << "Saving file " << filename << "failed with error" << saveFile.errorString();
         return false;
     }
 
-    /**
-     * if we used a QBuffer for kauth, try to move that to the real location with the helper
-     */
-    if (temporaryBuffer) {
-        // temporary buffer was used to save the file
-        // -> computing checksum
-        // -> saving to temporary file
-        // -> copying the temporary file to the original file location with KAuth action
-        QTemporaryFile tempFile;
-        if (!tempFile.open()) {
+    return true;
+}
+
+TextBuffer::SaveResult TextBuffer::saveBufferUnprivileged(const QString &filename)
+{
+    if (m_alwaysUseKAuthForSave) {
+        // unit-testing mode, simulate we need privileges
+        return SaveResult::MissingPermissions;
+    }
+
+    // construct correct filter device
+    // we try to use the same compression as for opening
+    const KCompressionDevice::CompressionType type = KFilterDev::compressionTypeForMimeType(m_mimeTypeForFilterDev);
+    QScopedPointer<KCompressionDevice> saveFile(new KCompressionDevice(filename, type));
+
+    if (!saveFile->open(QIODevice::WriteOnly)) {
+#ifdef CAN_USE_ERRNO
+        if (errno != EACCES) {
+            return SaveResult::Failed;
+        }
+#endif
+        return SaveResult::MissingPermissions;
+    }
+
+    if (!saveBuffer(filename, *saveFile)) {
+        return SaveResult::Failed;
+    }
+
+    return SaveResult::Success;
+}
+
+bool TextBuffer::saveBufferEscalated(const QString &filename)
+{
+    // construct correct filter device
+    // we try to use the same compression as for opening
+    const KCompressionDevice::CompressionType type = KFilterDev::compressionTypeForMimeType(m_mimeTypeForFilterDev);
+    QScopedPointer<KCompressionDevice> saveFile(new KCompressionDevice(filename, type));
+    uint ownerId = -2;
+    uint groupId = -2;
+    QScopedPointer<QIODevice> temporaryBuffer;
+
+    // Memorize owner and group.
+    const QFileInfo fileInfo(filename);
+    if (fileInfo.exists()) {
+        ownerId = fileInfo.ownerId();
+        groupId = fileInfo.groupId();
+    }
+
+    // if that fails we need more privileges to save this file
+    // -> we write to a temporary file and then send its path to KAuth action for privileged save
+    temporaryBuffer.reset(new QBuffer());
+
+    // open buffer for write and read (read is used for checksum computing and writing to temporary file)
+    if (!temporaryBuffer->open(QIODevice::ReadWrite)) {
+        return false;
+    }
+
+    // we are now saving to a temporary buffer with potential compression proxy
+    saveFile.reset(new KCompressionDevice(temporaryBuffer.data(), false, type));
+    if (!saveFile->open(QIODevice::WriteOnly)) {
+        return false;
+    }
+
+    if (!saveBuffer(filename, *saveFile)) {
+        return false;
+    }
+
+    // temporary buffer was used to save the file
+    // -> computing checksum
+    // -> saving to temporary file
+    // -> copying the temporary file to the original file location with KAuth action
+    QTemporaryFile tempFile;
+    if (!tempFile.open()) {
+        return false;
+    }
+
+    // go to QBuffer start
+    temporaryBuffer->seek(0);
+
+    // read contents of QBuffer and add them to checksum utility as well as to QTemporaryFile
+    char buffer[bufferLength];
+    qint64 read = -1;
+    QCryptographicHash cryptographicHash(SecureTextBuffer::checksumAlgorithm);
+    while ((read = temporaryBuffer->read(buffer, bufferLength)) > 0) {
+        cryptographicHash.addData(buffer, read);
+        if (tempFile.write(buffer, read) == -1) {
             return false;
         }
+    }
+    if (!tempFile.flush()) {
+        return false;
+    }
 
-        // go to QBuffer start
-        temporaryBuffer->seek(0);
+    // prepare data for KAuth action
+    QVariantMap kAuthActionArgs;
+    kAuthActionArgs.insert(QStringLiteral("sourceFile"), tempFile.fileName());
+    kAuthActionArgs.insert(QStringLiteral("targetFile"), filename);
+    kAuthActionArgs.insert(QStringLiteral("checksum"), cryptographicHash.result());
+    kAuthActionArgs.insert(QStringLiteral("ownerId"), ownerId);
+    kAuthActionArgs.insert(QStringLiteral("groupId"), groupId);
 
-        // read contents of QBuffer and add them to checksum utility as well as to QTemporaryFile
-        char buffer[bufferLength];
-        qint64 read = -1;
-        QCryptographicHash cryptographicHash(SecureTextBuffer::checksumAlgorithm);
-        while ((read = temporaryBuffer->read(buffer, bufferLength)) > 0) {
-            cryptographicHash.addData(buffer, read);
-            if (tempFile.write(buffer, read) == -1) {
-                return false;
-            }
-        }
-        if (!tempFile.flush()) {
+    // call save with elevated privileges
+    if (KTextEditor::EditorPrivate::unitTestMode()) {
+        // unit testing purposes only
+        if (!SecureTextBuffer::savefile(kAuthActionArgs).succeeded()) {
             return false;
         }
-
-        // prepare data for KAuth action
-        QVariantMap kAuthActionArgs;
-        kAuthActionArgs.insert(QLatin1String("sourceFile"), tempFile.fileName());
-        kAuthActionArgs.insert(QLatin1String("targetFile"), filename);
-        kAuthActionArgs.insert(QLatin1String("checksum"), cryptographicHash.result());
-        kAuthActionArgs.insert(QLatin1String("ownerId"), ownerId);
-        kAuthActionArgs.insert(QLatin1String("groupId"), groupId);
-
-        // call save with elevated privileges
-        if (KTextEditor::EditorPrivate::unitTestMode()) {
-            // unit testing purposes only
-            if (!SecureTextBuffer::savefile(kAuthActionArgs).succeeded()) {
-                return false;
-            }
-        } else {
-            KAuth::Action kAuthSaveAction(QLatin1String("org.kde.ktexteditor.katetextbuffer.savefile"));
-            kAuthSaveAction.setHelperId(QLatin1String("org.kde.ktexteditor.katetextbuffer"));
-            kAuthSaveAction.setArguments(kAuthActionArgs);
-            KAuth::ExecuteJob *job = kAuthSaveAction.execute();
-            if (!job->exec()) {
-                return false;
-            }
+    } else {
+        KAuth::Action kAuthSaveAction(QStringLiteral("org.kde.ktexteditor.katetextbuffer.savefile"));
+        kAuthSaveAction.setHelperId(QStringLiteral("org.kde.ktexteditor.katetextbuffer"));
+        kAuthSaveAction.setArguments(kAuthActionArgs);
+        KAuth::ExecuteJob *job = kAuthSaveAction.execute();
+        if (!job->exec()) {
+            return false;
         }
     }
 
-    // remember this revision as last saved
-    m_history.setLastSavedRevision();
-
-    // inform that we have saved the state
-    markModifiedLinesAsSaved();
-
-    // emit that file was saved and be done
-    emit saved(filename);
     return true;
 }
 
 void TextBuffer::notifyAboutRangeChange(KTextEditor::View *view, int startLine, int endLine, bool rangeWithAttribute)
 {
-    /**
-     * ignore calls if no document is around
-     */
+    // ignore calls if no document is around
     if (!m_document) {
         return;
     }
 
-    /**
-     * update all views, this IS ugly and could be a signal, but I profiled and a signal is TOO slow, really
-     * just create 20k ranges in a go and you wait seconds on a decent machine
-     */
-    const QList<KTextEditor::View *> &views = m_document->views();
-    foreach (KTextEditor::View *curView, views) {
+    // update all views, this IS ugly and could be a signal, but I profiled and a signal is TOO slow, really
+    // just create 20k ranges in a go and you wait seconds on a decent machine
+    const QList<KTextEditor::View *> views = m_document->views();
+    for (KTextEditor::View *curView : views) {
         // filter wrong views
         if (view && view != curView) {
             continue;
@@ -963,7 +945,7 @@ void TextBuffer::notifyAboutRangeChange(KTextEditor::View *view, int startLine,
 
 void TextBuffer::markModifiedLinesAsSaved()
 {
-    foreach (TextBlock *block, m_blocks) {
+    for (TextBlock *block : qAsConst(m_blocks)) {
         block->markModifiedLinesAsSaved();
     }
 }
@@ -975,32 +957,25 @@ QList<TextRange *> TextBuffer::rangesForLine(int line, KTextEditor::View *view,
 
     // get the ranges of the right block
     QList<TextRange *> rightRanges;
-    foreach (const QSet<TextRange *> &ranges, m_blocks.at(blockIndex)->rangesForLine(line)) {
-        foreach (TextRange *const range, ranges) {
-            /**
-            * we want only ranges with attributes, but this one has none
-            */
+    const auto blockRanges = m_blocks.at(blockIndex)->rangesForLine(line);
+    for (const QSet<TextRange *> &ranges : blockRanges) {
+        for (TextRange *const range : ranges) {
+            // we want only ranges with attributes, but this one has none
             if (rangesWithAttributeOnly && !range->hasAttribute()) {
                 continue;
             }
 
-            /**
-            * we want ranges for no view, but this one's attribute is only valid for views
-            */
+            // we want ranges for no view, but this one's attribute is only valid for views
             if (!view && range->attributeOnlyForViews()) {
                 continue;
             }
 
-            /**
-            * the range's attribute is not valid for this view
-            */
+            // the range's attribute is not valid for this view
             if (range->view() && range->view() != view) {
                 continue;
             }
 
-            /**
-            * if line is in the range, ok
-            */
+            // if line is in the range, ok
             if (range->startInternal().lineInternal() <= line && line <= range->endInternal().lineInternal()) {
                 rightRanges.append(range);
             }
