@@ -1,55 +1,40 @@
-/*  This file is part of the KDE libraries and the Kate part.
- *
- *  Copyright (C) 2003 Anders Lund <anders.lund@lund.tdcadsl.dk>
- *  Copyright (C) 2010 Christoph Cullmann <cullmann@kde.org>
- *
- *  This library is free software; you can redistribute it and/or
- *  modify it under the terms of the GNU Library General Public
- *  License as published by the Free Software Foundation; either
- *  version 2 of the License, or (at your option) any later version.
- *
- *  This library is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- *  Library General Public License for more details.
- *
- *  You should have received a copy of the GNU Library General Public License
- *  along with this library; see the file COPYING.LIB.  If not, write to
- *  the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- *  Boston, MA 02110-1301, USA.
- */
+/*
+    SPDX-FileCopyrightText: 2003 Anders Lund <anders.lund@lund.tdcadsl.dk>
+    SPDX-FileCopyrightText: 2010 Christoph Cullmann <cullmann@kde.org>
+
+    SPDX-License-Identifier: LGPL-2.0-or-later
+*/
 
 // BEGIN includes
 #include "katewordcompletion.h"
-#include "kateview.h"
 #include "kateconfig.h"
+#include "katedefaultcolors.h"
 #include "katedocument.h"
 #include "kateglobal.h"
 #include "katepartdebug.h"
-#include "katedefaultcolors.h"
-#include "katehighlight.h"
+#include "kateview.h"
 
 #include <ktexteditor/movingrange.h>
 #include <ktexteditor/range.h>
 
-#include <KLocalizedString>
-#include <KPluginFactory>
+#include <KAboutData>
 #include <KActionCollection>
-#include <KParts/Part>
+#include <KConfigGroup>
+#include <KLocalizedString>
 #include <KPageDialog>
 #include <KPageWidgetModel>
+#include <KParts/Part>
+#include <KPluginFactory>
 #include <KToggleAction>
-#include <KConfigGroup>
-#include <KAboutData>
 
-#include <QRegularExpression>
-#include <QSet>
-#include <QString>
 #include <QAction>
 #include <QCheckBox>
 #include <QLabel>
 #include <QLayout>
+#include <QRegularExpression>
+#include <QSet>
 #include <QSpinBox>
+#include <QString>
 
 // END
 
@@ -86,10 +71,10 @@ QVariant KateWordCompletionModel::data(const QModelIndex &index, int role) const
     if (!index.parent().isValid()) {
         // It is the group header
         switch (role) {
-            case Qt::DisplayRole:
-                return i18n("Auto Word Completion");
-            case GroupRole:
-                return Qt::DisplayRole;
+        case Qt::DisplayRole:
+            return i18n("Auto Word Completion");
+        case GroupRole:
+            return Qt::DisplayRole;
         }
     }
 
@@ -211,7 +196,6 @@ QStringList KateWordCompletionModel::allMatches(KTextEditor::View *view, const K
     QSet<QString> result;
     const int minWordSize = qMax(2, qobject_cast<KTextEditor::ViewPrivate *>(view)->config()->wordCompletionMinimalWordLength());
     const int lines = view->document()->lines();
-    KateHighlighting *h = qobject_cast<KTextEditor::ViewPrivate *>(view)->doc()->highlight();
     for (int line = 0; line < lines; line++) {
         const QString &text = view->document()->line(line);
         int wordBegin = 0;
@@ -221,11 +205,9 @@ QStringList KateWordCompletionModel::allMatches(KTextEditor::View *view, const K
         while (offset < end) {
             const QChar c = text.at(offset);
             // increment offset when at line end, so we take the last character too
-            if (!h->isInWord(c) || (offset == end - 1 && offset++)) {
+            if ((! c.isLetterOrNumber() && c != QLatin1Char('_')) || (offset == end - 1 && offset++)) {
                 if (offset - wordBegin > minWordSize && (line != range.end().line() || offset != range.end().column())) {
-                    /**
-                     * don't add the word we are inside with cursor!
-                     */
+                    // don't add the word we are inside with cursor!
                     if (!cursorLine || (view->cursorPosition().column() < wordBegin || view->cursorPosition().column() > offset)) {
                         result.insert(text.mid(wordBegin, offset - wordBegin));
                     }
@@ -244,13 +226,14 @@ QStringList KateWordCompletionModel::allMatches(KTextEditor::View *view, const K
 void KateWordCompletionModel::executeCompletionItem(KTextEditor::View *view, const KTextEditor::Range &word, const QModelIndex &index) const
 {
     KTextEditor::ViewPrivate *v = qobject_cast<KTextEditor::ViewPrivate *>(view);
-    KateHighlighting *h = v->doc()->highlight();
     if (v->config()->wordCompletionRemoveTail()) {
         int tailStart = word.end().column();
         const QString &line = view->document()->line(word.end().line());
         int tailEnd = line.length();
         for (int i = word.end().column(); i < tailEnd; ++i) {
-            if (!h->isInWord(line[i])) {
+            // Letters, numbers and underscore are part of a word!
+            /// \todo Introduce configurable \e word-separators??
+            if (!line[i].isLetterOrNumber() && line[i] != QLatin1Char('_')) {
                 tailEnd = i;
             }
         }
@@ -290,10 +273,9 @@ KTextEditor::Range KateWordCompletionModel::completionRange(KTextEditor::View *v
     int col = position.column();
 
     KTextEditor::Document *doc = view->document();
-    KateHighlighting *h = qobject_cast<KTextEditor::ViewPrivate *>(view)->doc()->highlight();
     while (col > 0) {
         const QChar c = (doc->characterAt(KTextEditor::Cursor(line, col - 1)));
-        if (h->isInWord(c)) {
+        if (c.isLetterOrNumber() || c.isMark() || c == QLatin1Char('_')) {
             col--;
             continue;
         }
