@@ -1,34 +1,21 @@
-/*  This file is part of the KDE libraries and the Kate part.
- *
- *  Copyright (C) 2002-2010 Anders Lund <anders@alweb.dk>
- *
- *  Rewritten based on code of Copyright (c) 2002 Michael Goffioul <kdeprint@swing.be>
- *
- *  This library is free software; you can redistribute it and/or
- *  modify it under the terms of the GNU Library General Public
- *  License as published by the Free Software Foundation; either
- *  version 2 of the License, or (at your option) any later version.
- *
- *  This library is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- *  Library General Public License for more details.
- *
- *  You should have received a copy of the GNU Library General Public License
- *  along with this library; see the file COPYING.LIB.  If not, write to
- *  the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- *  Boston, MA 02110-1301, USA.
- */
+/*
+    SPDX-FileCopyrightText: 2002-2010 Anders Lund <anders@alweb.dk>
+
+    Rewritten based on code of:
+    SPDX-FileCopyrightText: 2002 Michael Goffioul <kdeprint@swing.be>
+
+    SPDX-License-Identifier: LGPL-2.0-or-later
+*/
 
 #include "printpainter.h"
 
-#include "katetextfolding.h"
-#include "katedocument.h"
 #include "katebuffer.h"
-#include "kateview.h"
+#include "katedocument.h"
 #include "katehighlight.h"
 #include "katepartdebug.h"
+#include "katetextfolding.h"
 #include "katetextlayout.h"
+#include "kateview.h"
 
 #include <KLocalizedString>
 #include <KUser>
@@ -45,7 +32,8 @@ public:
         : headerTagList()
         , footerTagList()
         , selectionRange()
-    {}
+    {
+    }
 
     uint pageWidth = 0;
     uint pageHeight = 0;
@@ -174,7 +162,7 @@ void PrintPainter::updateCache()
     QString s = QStringLiteral("%1 ").arg(m_doc->lines());
     s.fill(QLatin1Char('5'), -1); // some non-fixed fonts haven't equally wide numbers
     // FIXME calculate which is actually the widest...
-    m_lineNumberWidth = m_renderer->currentFontMetrics().width(s);
+    m_lineNumberWidth = m_renderer->currentFontMetrics().boundingRect(s).width();
 }
 
 void PrintPainter::paint(QPrinter *printer) const
@@ -210,7 +198,7 @@ void PrintPainter::paint(QPrinter *printer) const
             painter.translate(pl.xstart, y);
         }
 
-        if (m_printLineNumbers /*&& ! startCol*/) {   // don't repeat!
+        if (m_printLineNumbers /*&& ! startCol*/) { // don't repeat!
             paintLineNumber(painter, lineCount, pl);
         }
 
@@ -244,7 +232,7 @@ void PrintPainter::configure(const QPrinter *printer, PageLayout &pl) const
 
     if (m_printLineNumbers) {
         // a small space between the line numbers and the text
-        int _adj = m_renderer->currentFontMetrics().width(QStringLiteral("5"));
+        int _adj = m_renderer->currentFontMetrics().horizontalAdvance(QStringLiteral("5"));
         // adjust available width and set horizontal start point for data
         pl.maxWidth -= m_lineNumberWidth + _adj;
         pl.xstart += m_lineNumberWidth + _adj;
@@ -261,13 +249,13 @@ void PrintPainter::configure(const QPrinter *printer, PageLayout &pl) const
         KUser u(KUser::UseRealUserID);
         tags[QStringLiteral("u")] = u.loginName();
 
-        tags[QStringLiteral("d")] =  QLocale().toString(dt, QLocale::ShortFormat);
-        tags[QStringLiteral("D")] =  QLocale().toString(dt, QLocale::LongFormat);
-        tags[QStringLiteral("h")] =  QLocale().toString(dt.time(), QLocale::ShortFormat);
-        tags[QStringLiteral("y")] =  QLocale().toString(dt.date(), QLocale::ShortFormat);
-        tags[QStringLiteral("Y")] =  QLocale().toString(dt.date(), QLocale::LongFormat);
-        tags[QStringLiteral("f")] =  m_doc->url().fileName();
-        tags[QStringLiteral("U")] =  m_doc->url().toString();
+        tags[QStringLiteral("d")] = QLocale().toString(dt, QLocale::ShortFormat);
+        tags[QStringLiteral("D")] = QLocale().toString(dt, QLocale::LongFormat);
+        tags[QStringLiteral("h")] = QLocale().toString(dt.time(), QLocale::ShortFormat);
+        tags[QStringLiteral("y")] = QLocale().toString(dt.date(), QLocale::ShortFormat);
+        tags[QStringLiteral("Y")] = QLocale().toString(dt.date(), QLocale::LongFormat);
+        tags[QStringLiteral("f")] = m_doc->url().fileName();
+        tags[QStringLiteral("U")] = m_doc->url().toString();
         if (pl.selectionOnly) {
             QString s(i18n("(Selection of) "));
             tags[QStringLiteral("f")].prepend(s);
@@ -338,7 +326,7 @@ void PrintPainter::configure(const QPrinter *printer, PageLayout &pl) const
 
     if (m_useBox) {
         // set maxwidth to something sensible
-        pl.maxWidth -= (m_boxWidth + pl.innerMargin)  * 2;
+        pl.maxWidth -= (m_boxWidth + pl.innerMargin) * 2;
         pl.xstart += m_boxWidth + pl.innerMargin;
         // maxheight too..
         pl.maxHeight -= m_boxWidth;
@@ -374,12 +362,11 @@ void PrintPainter::configure(const QPrinter *printer, PageLayout &pl) const
             totalLines += rangeptr->viewLineCount();
         }
 
-        const int totalPages = (totalLines / linesPerPage)
-                               + ((totalLines % linesPerPage) > 0 ? 1 : 0);
+        const int totalPages = (totalLines / linesPerPage) + ((totalLines % linesPerPage) > 0 ? 1 : 0);
 
         // TODO: add space for guide if required
-//         if ( useGuide )
-//           _lt += (guideHeight + (fontHeight /2)) / fontHeight;
+        //         if ( useGuide )
+        //           _lt += (guideHeight + (fontHeight /2)) / fontHeight;
 
         // substitute both tag lists
         QString re(QStringLiteral("%P"));
@@ -448,9 +435,9 @@ void PrintPainter::paintHeader(QPainter &painter, const uint currentPage, uint &
         }
     }
 
-    if (!(m_useHeaderBackground || m_useBox || m_useBackground)) {  // draw a 1 px (!?) line to separate header from contents
+    if (!(m_useHeaderBackground || m_useBox || m_useBackground)) { // draw a 1 px (!?) line to separate header from contents
         painter.drawLine(0, pl.headerHeight - 1, pl.headerWidth, pl.headerHeight - 1);
-        //y += 1; now included in headerHeight
+        // y += 1; now included in headerHeight
     }
 
     painter.restore();
@@ -464,7 +451,7 @@ void PrintPainter::paintFooter(QPainter &painter, const uint currentPage, const
     painter.setPen(QPen(m_footerForeground, 0.5));
     painter.setFont(m_fhFont);
 
-    if (!(m_useFooterBackground || m_useBox || m_useBackground)) {// draw a 1 px (!?) line to separate footer from contents
+    if (!(m_useFooterBackground || m_useBox || m_useBackground)) { // draw a 1 px (!?) line to separate footer from contents
         painter.drawLine(0, pl.pageHeight - pl.footerHeight - 1, pl.headerWidth, pl.pageHeight - pl.footerHeight - 1);
     }
     if (m_useFooterBackground) {
@@ -521,13 +508,11 @@ void PrintPainter::paintGuide(QPainter &painter, uint &y, const PageLayout &pl)
     }
 
     // draw a title string
-    QFont _titleFont = m_renderer->config()->font();
+    QFont _titleFont = m_renderer->currentFont();
     _titleFont.setBold(true);
     painter.setFont(_titleFont);
     QRect _r;
-    painter.drawText(QRect(_marg, y, pl.pageWidth - (2 * _marg), pl.maxHeight - y),
-                     Qt::AlignTop | Qt::AlignHCenter,
-                     i18n("Typographical Conventions for %1", _hlName), &_r);
+    painter.drawText(QRect(_marg, y, pl.pageWidth - (2 * _marg), pl.maxHeight - y), Qt::AlignTop | Qt::AlignHCenter, i18n("Typographical Conventions for %1", _hlName), &_r);
     const int _w = pl.pageWidth - (_marg * 2) - (pl.innerMargin * 2);
     const int _x = _marg + pl.innerMargin;
     y += _r.height() + pl.innerMargin;
@@ -535,8 +520,9 @@ void PrintPainter::paintGuide(QPainter &painter, uint &y, const PageLayout &pl)
     y += 1 + pl.innerMargin;
 
     int _widest(0);
-    foreach (const KTextEditor::Attribute::Ptr &attribute, _attributes) {
-        _widest = qMax(QFontMetrics(attribute->font()).width(attribute->name().section(QLatin1Char(':'), 1, 1)), _widest);
+    for (const KTextEditor::Attribute::Ptr &attribute : qAsConst(_attributes)) {
+        const QString _name = attribute->name().section(QLatin1Char(':'), 1, 1);
+        _widest = qMax(QFontMetrics(attribute->font()).boundingRect(_name).width(), _widest);
     }
 
     const int _guideCols = _w / (_widest + pl.innerMargin);
@@ -547,7 +533,7 @@ void PrintPainter::paintGuide(QPainter &painter, uint &y, const PageLayout &pl)
 
     _titleFont.setUnderline(true);
     QString _currentHlName;
-    foreach (const KTextEditor::Attribute::Ptr &attribute, _attributes) {
+    for (const KTextEditor::Attribute::Ptr &attribute : qAsConst(_attributes)) {
         QString _hl = attribute->name().section(QLatin1Char(':'), 0, 0);
         QString _name = attribute->name().section(QLatin1Char(':'), 1, 1);
         if (_hl != _hlName && _hl != _currentHlName) {
@@ -563,14 +549,14 @@ void PrintPainter::paintGuide(QPainter &painter, uint &y, const PageLayout &pl)
             _i = 0;
         }
 
-        KTextEditor::Attribute _attr =  *_defaultAttributes[attribute->defaultStyle()];
+        KTextEditor::Attribute _attr = *_defaultAttributes[attribute->defaultStyle()];
         _attr += *attribute;
         painter.setPen(_attr.foreground().color());
         painter.setFont(_attr.font());
 
         if (_attr.hasProperty(QTextFormat::BackgroundBrush)) {
             QRect _rect = QFontMetrics(_attr.font()).boundingRect(_name);
-            _rect.moveTo(_x + ((_i % _guideCols)*_cw), y);
+            _rect.moveTo(_x + ((_i % _guideCols) * _cw), y);
             painter.fillRect(_rect, _attr.background());
         }
 
@@ -583,7 +569,7 @@ void PrintPainter::paintGuide(QPainter &painter, uint &y, const PageLayout &pl)
     }
 
     if (_i % _guideCols) {
-        y += m_fontHeight;// last row not full
+        y += m_fontHeight; // last row not full
     }
     // draw a box around the legend
     painter.setPen(_defaultPen);
@@ -612,7 +598,7 @@ void PrintPainter::paintBox(QPainter &painter, uint &y, const PageLayout &pl) co
         y += pl.innerMargin;
     }
 
-    if (m_useFooter) {   // drawline is not trustable, grr.
+    if (m_useFooter) { // drawline is not trustable, grr.
         painter.fillRect(0, pl.maxHeight + pl.innerMargin, pl.headerWidth, m_boxWidth, m_boxColor);
     }
 
@@ -704,10 +690,10 @@ void PrintPainter::paintLineNumber(QPainter &painter, const uint number, const P
     const int left = ((m_useBox || m_useBackground) ? pl.innerMargin : 0) - pl.xstart;
 
     painter.save();
-    painter.setFont(m_renderer->config()->font());
+    painter.setFont(m_renderer->currentFont());
     painter.setPen(m_renderer->config()->lineNumberColor());
-    painter.drawText(left,  0, m_lineNumberWidth, m_fontHeight, Qt::AlignRight, QString::number(number + 1));
+    painter.drawText(left, 0, m_lineNumberWidth, m_fontHeight, Qt::AlignRight, QString::number(number + 1));
     painter.restore();
 }
 
-//END PrintPainter
+// END PrintPainter
