@@ -1,24 +1,13 @@
-/* This file is part of the KDE libraries
-   Copyright (C) 2007 Mirko Stocker <me@misto.ch>
-   Copyright (C) 2003-2005 Hamish Rodda <rodda@kde.org>
-   Copyright (C) 2001 Christoph Cullmann <cullmann@kde.org>
-   Copyright (C) 2001 Joseph Wenninger <jowenn@kde.org>
-   Copyright (C) 1999 Jochen Wilhelmy <digisnap@cs.tu-berlin.de>
-   Copyright (C) 2013 Andrey Matveyakin <a.matveyakin@gmail.com>
+/*
+    This file is part of the KDE libraries
+    SPDX-FileCopyrightText: 2007 Mirko Stocker <me@misto.ch>
+    SPDX-FileCopyrightText: 2003-2005 Hamish Rodda <rodda@kde.org>
+    SPDX-FileCopyrightText: 2001 Christoph Cullmann <cullmann@kde.org>
+    SPDX-FileCopyrightText: 2001 Joseph Wenninger <jowenn@kde.org>
+    SPDX-FileCopyrightText: 1999 Jochen Wilhelmy <digisnap@cs.tu-berlin.de>
+    SPDX-FileCopyrightText: 2013 Andrey Matveyakin <a.matveyakin@gmail.com>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License version 2 as published by the Free Software Foundation.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-only
 */
 
 #include "katerenderer.h"
@@ -763,39 +752,6 @@ void KateRenderer::paintTextLine(QPainter &paint, KateLineLayoutPtr range, int x
             }
         }
 
-        // Draw inline notes
-        if (!isPrinterFriendly()) {
-            const auto inlineNotes = m_view->inlineNotes(range->line());
-            for (const auto &inlineNoteData : inlineNotes) {
-                KTextEditor::InlineNote inlineNote(inlineNoteData);
-                const int column = inlineNote.position().column();
-                int viewLine = range->viewLineForColumn(column);
-
-                // Determine the position where to paint the note.
-                // We start by getting the x coordinate of cursor placed to the column.
-                qreal x = range->viewLine(viewLine).lineLayout().cursorToX(column) - xStart;
-                int textLength = range->length();
-                if (column == 0 || column < textLength) {
-                    // If the note is inside text or at the beginning, then there is a hole in the text where the
-                    // note should be painted and the cursor gets placed at the right side of it. So we have to
-                    // subtract the width of the note to get to left side of the hole.
-                    x -= inlineNote.width();
-                } else {
-                    // If the note is outside the text, then the X coordinate is located at the end of the line.
-                    // Add appropriate amount of spaces to reach the required column.
-                    x += spaceWidth() * (column - textLength);
-                }
-
-                qreal y = lineHeight() * viewLine;
-
-                // Paint the note
-                paint.save();
-                paint.translate(x, y);
-                inlineNote.provider()->paintInlineNote(inlineNote, paint);
-                paint.restore();
-            }
-        }
-
         // draw word-wrap-honor-indent filling
         if ((range->viewLineCount() > 1) && range->shiftX() && (range->shiftX() > xStart)) {
             if (backgroundBrushSet)
@@ -889,6 +845,39 @@ void KateRenderer::paintTextLine(QPainter &paint, KateLineLayoutPtr range, int x
         paint.drawLine(_x, 0, _x, lineHeight());
         paint.setRenderHints(backupRenderHints);
     }
+
+    // Draw inline notes
+    if (!isPrinterFriendly()) {
+        const auto inlineNotes = m_view->inlineNotes(range->line());
+        for (const auto &inlineNoteData : inlineNotes) {
+            KTextEditor::InlineNote inlineNote(inlineNoteData);
+            const int column = inlineNote.position().column();
+            int viewLine = range->viewLineForColumn(column);
+
+            // Determine the position where to paint the note.
+            // We start by getting the x coordinate of cursor placed to the column.
+            qreal x = range->viewLine(viewLine).lineLayout().cursorToX(column) - xStart;
+            int textLength = range->length();
+            if (column == 0 || column < textLength) {
+                // If the note is inside text or at the beginning, then there is a hole in the text where the
+                // note should be painted and the cursor gets placed at the right side of it. So we have to
+                // subtract the width of the note to get to left side of the hole.
+                x -= inlineNote.width();
+            } else {
+                // If the note is outside the text, then the X coordinate is located at the end of the line.
+                // Add appropriate amount of spaces to reach the required column.
+                x += spaceWidth() * (column - textLength);
+            }
+
+            qreal y = lineHeight() * viewLine;
+
+            // Paint the note
+            paint.save();
+            paint.translate(x, y);
+            inlineNote.provider()->paintInlineNote(inlineNote, paint);
+            paint.restore();
+        }
+    }
 }
 
 uint KateRenderer::fontHeight() const
@@ -959,27 +948,24 @@ void KateRenderer::updateConfig()
 
 void KateRenderer::updateFontHeight()
 {
-    /**
-     * cache font + metrics
-     */
+    // cache font + metrics
     m_font = config()->baseFont();
     m_fontMetrics = QFontMetricsF(m_font);
 
-    /**
-     * ensure minimal height of one pixel to not fall in the div by 0 trap somewhere
-     *
-     * use a line spacing that matches the code in qt to layout/paint text
-     *
-     * see bug 403868
-     * https://github.com/qt/qtbase/blob/5.12/src/gui/text/qtextlayout.cpp (line 2270 at the moment) where the text height is set as:
-     *
-     * qreal height = maxY + fontHeight - minY;
-     *
-     * with fontHeight:
-     *
-     * qreal fontHeight = font.ascent() + font.descent();
-     */
+    // ensure minimal height of one pixel to not fall in the div by 0 trap somewhere
+    //
+    // use a line spacing that matches the code in qt to layout/paint text
+    //
+    // see bug 403868
+    // https://github.com/qt/qtbase/blob/5.12/src/gui/text/qtextlayout.cpp (line 2270 at the moment) where the text height is set as:
+    //
+    // qreal height = maxY + fontHeight - minY;
+    //
+    // with fontHeight:
+    //
+    // qreal fontHeight = font.ascent() + font.descent();
     m_fontHeight = qMax(1, qCeil(m_fontMetrics.ascent() + m_fontMetrics.descent()));
+    m_fontAscent = m_fontMetrics.ascent();
 }
 
 void KateRenderer::updateMarkerSize()
@@ -1084,12 +1070,14 @@ void KateRenderer::layoutLine(KateLineLayoutPtr lineLayout, int maxwidth, bool c
 
         if (maxwidth > 0) {
             line.setLineWidth(maxwidth);
+        } else {
+            line.setLineWidth(INT_MAX);
         }
 
         // we include the leading, this must match the ::updateFontHeight code!
         line.setLeadingIncluded(true);
 
-        line.setPosition(QPoint(line.lineNumber() ? shiftX : firstLineOffset, height));
+        line.setPosition(QPoint(line.lineNumber() ? shiftX : firstLineOffset, height - line.ascent() + m_fontAscent));
 
         if (needShiftX && line.width() > 0) {
             needShiftX = false;
