@@ -1,22 +1,9 @@
-/* This file is part of the KDE libraries
-   Copyright (C) 2001-2003 Christoph Cullmann <cullmann@kde.org>
-   Copyright (C) 2002, 2003 Anders Lund <anders.lund@lund.tdcadsl.dk>
- *
- *  This library is free software; you can redistribute it and/or
- *  modify it under the terms of the GNU Library General Public
- *  License as published by the Free Software Foundation; either
- *  version 2 of the License, or (at your option) any later version.
- *
- *  This library is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- *  Library General Public License for more details.
- *
- *  You should have received a copy of the GNU Library General Public License
- *  along with this library; see the file COPYING.LIB.  If not, write to
- *  the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- *  Boston, MA 02110-1301, USA.
- */
+/*
+    SPDX-FileCopyrightText: 2001-2003 Christoph Cullmann <cullmann@kde.org>
+    SPDX-FileCopyrightText: 2002, 2003 Anders Lund <anders.lund@lund.tdcadsl.dk>
+
+    SPDX-License-Identifier: LGPL-2.0-or-later
+*/
 
 #ifndef KATE_SCHEMA_H
 #define KATE_SCHEMA_H
@@ -25,10 +12,13 @@
 #include <KConfig>
 #include <KLocalizedString>
 
-#include <QStringList>
 #include <QPointer>
+#include <QStringList>
 
-namespace KTextEditor { class ViewPrivate; }
+namespace KTextEditor
+{
+class ViewPrivate;
+}
 class QActionGroup;
 
 class KateSchema
@@ -100,7 +90,7 @@ private:
     QActionGroup *m_group;
     int last;
 
-public  Q_SLOTS:
+public Q_SLOTS:
     void slotAboutToShow();
 
 private Q_SLOTS:
@@ -108,4 +98,3 @@ private Q_SLOTS:
 };
 
 #endif
-
