@@ -1,33 +1,20 @@
-/* This file is part of the KDE libraries
-   Copyright (C) 2001-2003 Christoph Cullmann <cullmann@kde.org>
-   Copyright (C) 2002, 2003 Anders Lund <anders.lund@lund.tdcadsl.dk>
-   Copyright (C) 2012 Dominik Haumann <dhaumann kde org>
- *
- *  This library is free software; you can redistribute it and/or
- *  modify it under the terms of the GNU Library General Public
- *  License as published by the Free Software Foundation; either
- *  version 2 of the License, or (at your option) any later version.
- *
- *  This library is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- *  Library General Public License for more details.
- *
- *  You should have received a copy of the GNU Library General Public License
- *  along with this library; see the file COPYING.LIB.  If not, write to
- *  the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- *  Boston, MA 02110-1301, USA.
- */
+/*
+    SPDX-FileCopyrightText: 2001-2003 Christoph Cullmann <cullmann@kde.org>
+    SPDX-FileCopyrightText: 2002, 2003 Anders Lund <anders.lund@lund.tdcadsl.dk>
+    SPDX-FileCopyrightText: 2012-2018 Dominik Haumann <dhaumann@kde.org>
 
-#ifndef __KATE_SCHEMA_CONFIG_H__
-#define __KATE_SCHEMA_CONFIG_H__
+    SPDX-License-Identifier: LGPL-2.0-or-later
+*/
+
+#ifndef KATE_SCHEMA_CONFIG_H
+#define KATE_SCHEMA_CONFIG_H
 
-#include "katedialogs.h"
 #include "katecolortreewidget.h"
+#include "katedialogs.h"
 #include "kateextendedattribute.h"
 
-#include <QMap>
 #include <QFont>
+#include <QMap>
 
 class KateStyleTreeWidget;
 class KComboBox;
@@ -60,7 +47,7 @@ private:
 
 private:
     // multiple shemas may be edited. Hence, we need one ColorList for each schema
-    QMap<QString, QVector<KateColorItem> > m_schemas;
+    QMap<QString, QVector<KateColorItem>> m_schemas;
     QString m_currentSchema;
 
     KateColorTreeWidget *ui;
@@ -102,8 +89,8 @@ class KateSchemaConfigDefaultStylesTab : public QWidget
     Q_OBJECT
 
 public:
-    KateSchemaConfigDefaultStylesTab(KateSchemaConfigColorTab *colorTab);
-    ~KateSchemaConfigDefaultStylesTab();
+    explicit KateSchemaConfigDefaultStylesTab(KateSchemaConfigColorTab *colorTab);
+    ~KateSchemaConfigDefaultStylesTab() override;
 
 Q_SIGNALS:
     void changed();
@@ -118,7 +105,7 @@ public:
     void importSchema(const QString &schemaName, const QString &schema, KConfig *cfg);
 
 protected:
-    void showEvent(QShowEvent *event) Q_DECL_OVERRIDE;
+    void showEvent(QShowEvent *event) override;
     void updateColorPalette(const QColor &textColor);
 
 private:
@@ -134,7 +121,7 @@ class KateSchemaConfigHighlightTab : public QWidget
 
 public:
     explicit KateSchemaConfigHighlightTab(KateSchemaConfigDefaultStylesTab *page, KateSchemaConfigColorTab *colorTab);
-    ~KateSchemaConfigHighlightTab();
+    ~KateSchemaConfigHighlightTab() override;
 
     void schemaChanged(const QString &schema);
     void reload();
@@ -147,11 +134,11 @@ protected Q_SLOTS:
     void hlChanged(int z);
 
 public Q_SLOTS:
-    void exportHl(QString schema = QString(), int hl = -1, KConfig *cfg = 0);
-    void importHl(const QString &fromSchemaName = QString(), QString schema = QString(), int hl = -1, KConfig *cfg = 0);
+    void exportHl(QString schema = QString(), int hl = -1, KConfig *cfg = nullptr);
+    void importHl(const QString &fromSchemaName = QString(), QString schema = QString(), int hl = -1, KConfig *cfg = nullptr);
 
 protected:
-    void showEvent(QShowEvent *event) Q_DECL_OVERRIDE;
+    void showEvent(QShowEvent *event) override;
     void updateColorPalette(const QColor &textColor);
 
 private:
@@ -164,7 +151,7 @@ private:
     QString m_schema;
     int m_hl;
 
-    QHash<QString, QHash<int, QList<KTextEditor::Attribute::Ptr> > > m_hlDict;
+    QHash<QString, QHash<int, QVector<KTextEditor::Attribute::Ptr>>> m_hlDict;
 
 public:
     QList<int> hlsForSchema(const QString &schema);
@@ -177,16 +164,16 @@ class KateSchemaConfigPage : public KateConfigPage
 
 public:
     explicit KateSchemaConfigPage(QWidget *parent);
-    virtual ~KateSchemaConfigPage();
-    QString name() const Q_DECL_OVERRIDE;
-    QString fullName() const Q_DECL_OVERRIDE;
-    QIcon icon() const Q_DECL_OVERRIDE;
+    ~KateSchemaConfigPage() override;
+    QString name() const override;
+    QString fullName() const override;
+    QIcon icon() const override;
 
 public Q_SLOTS:
-    void apply() Q_DECL_OVERRIDE;
-    void reload() Q_DECL_OVERRIDE;
-    void reset() Q_DECL_OVERRIDE;
-    void defaults() Q_DECL_OVERRIDE;
+    void apply() override;
+    void reload() override;
+    void reset() override;
+    void defaults() override;
     void exportFullSchema();
     void importFullSchema();
 
@@ -213,4 +200,3 @@ private:
 };
 
 #endif
-
