@@ -1,22 +1,8 @@
-/*  This file is part of the KDE libraries and the Kate part.
- *
- *  Copyright (C) 2009 Dominik Haumann <dhaumann kde org>
- *
- *  This library is free software; you can redistribute it and/or
- *  modify it under the terms of the GNU Library General Public
- *  License as published by the Free Software Foundation; either
- *  version 2 of the License, or (at your option) any later version.
- *
- *  This library is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- *  Library General Public License for more details.
- *
- *  You should have received a copy of the GNU Library General Public License
- *  along with this library; see the file COPYING.LIB.  If not, write to
- *  the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- *  Boston, MA 02110-1301, USA.
- */
+/*
+    SPDX-FileCopyrightText: 2009-2018 Dominik Haumann <dhaumann@kde.org>
+
+    SPDX-License-Identifier: LGPL-2.0-or-later
+*/
 
 #ifndef KATE_COMMANDLINE_SCRIPT_H
 #define KATE_COMMANDLINE_SCRIPT_H
@@ -32,7 +18,8 @@ class KateCommandLineScriptHeader
 {
 public:
     KateCommandLineScriptHeader()
-    {}
+    {
+    }
 
     inline void setFunctions(const QStringList &functions)
     {
@@ -54,12 +41,11 @@ public:
 
 private:
     QStringList m_functions; ///< the functions the script contains
-    QJsonArray m_actions; ///< the action for this script
+    QJsonArray m_actions;    ///< the action for this script
 };
 
 /**
- * A specialized class for scripts that are of type
- * KateScriptInformation::IndentationScript
+ * A specialized class for scripts that are of type ScriptType::Indentation.
  */
 class KateCommandLineScript : public KateScript, public KTextEditor::Command
 {
@@ -69,7 +55,7 @@ public:
 
     const KateCommandLineScriptHeader &commandHeader();
 
-    bool callFunction(const QString &cmd, const QStringList args, QString &errorMessage);
+    bool callFunction(const QString &cmd, const QStringList &args, QString &errorMessage);
 
     //
     // KTextEditor::Command interface
