@@ -1,34 +1,22 @@
-// This file is part of the KDE libraries
-// Copyright (C) 2008 Paul Giannaros <paul@giannaros.org>
-// Copyright (C) 2009-2018 Dominik Haumann <dhaumann@kde.org>
-// Copyright (C) 2010 Joseph Wenninger <jowenn@kde.org>
-//
-// This library is free software; you can redistribute it and/or
-// modify it under the terms of the GNU Library General Public
-// License as published by the Free Software Foundation; either
-// version 2 of the License, or (at your option) version 3.
-//
-// This library is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-// Library General Public License for more details.
-//
-// You should have received a copy of the GNU Library General Public License
-// along with this library; see the file COPYING.LIB.  If not, write to
-// the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-// Boston, MA 02110-1301, USA.
+/*
+    SPDX-FileCopyrightText: 2008 Paul Giannaros <paul@giannaros.org>
+    SPDX-FileCopyrightText: 2009-2018 Dominik Haumann <dhaumann@kde.org>
+    SPDX-FileCopyrightText: 2010 Joseph Wenninger <jowenn@kde.org>
+
+    SPDX-License-Identifier: LGPL-2.0-or-later
+*/
 
 #include "katescript.h"
-#include "katescripteditor.h"
-#include "katescriptdocument.h"
-#include "katescriptview.h"
-#include "katescripthelpers.h"
-#include "kateview.h"
 #include "katedocument.h"
 #include "katepartdebug.h"
+#include "katescriptdocument.h"
+#include "katescripteditor.h"
+#include "katescripthelpers.h"
+#include "katescriptview.h"
+#include "kateview.h"
 
-#include <iostream>
 #include <KLocalizedString>
+#include <iostream>
 
 #include <QFile>
 #include <QFileInfo>
@@ -190,30 +178,26 @@ bool KateScript::load()
     return true;
 }
 
-QJSValue KateScript::evaluate(const QString& program, const FieldMap& env)
+QJSValue KateScript::evaluate(const QString &program, const FieldMap &env)
 {
-    if ( !load() ) {
-        qWarning() << "load of script failed:" << program;
+    if (!load()) {
+        qCWarning(LOG_KTE) << "load of script failed:" << program;
         return QJSValue();
     }
 
     // Wrap the arguments in a function to avoid polluting the global object
-    QString programWithContext = QLatin1String("(function(") +
-                                     QStringList(env.keys()).join(QLatin1Char(',')) +
-                                 QLatin1String(") { return ") +
-                                     program +
-                                 QLatin1String("})");
+    QString programWithContext = QLatin1String("(function(") + QStringList(env.keys()).join(QLatin1Char(',')) + QLatin1String(") { return ") + program + QLatin1String("})");
     QJSValue programFunction = m_engine->evaluate(programWithContext);
     Q_ASSERT(programFunction.isCallable());
 
     QJSValueList args;
-    for ( auto it = env.begin(); it != env.end(); it++ ) {
+    for (auto it = env.begin(); it != env.end(); it++) {
         args << it.value();
     }
 
     QJSValue result = programFunction.call(args);
     if (result.isError())
-        qWarning() << "Error evaluating script: " << result.toString();
+        qCWarning(LOG_KTE) << "Error evaluating script: " << result.toString();
 
     return result;
 }
