@@ -1,23 +1,10 @@
-/* This file is part of the KDE libraries
-   Copyright (C) 2001,2002 Joseph Wenninger <jowenn@kde.org>
-   Copyright (C) 2001 Christoph Cullmann <cullmann@kde.org>
-   Copyright (C) 1999 Jochen Wilhelmy <digisnap@cs.tu-berlin.de>
- *
- *  This library is free software; you can redistribute it and/or
- *  modify it under the terms of the GNU Library General Public
- *  License as published by the Free Software Foundation; either
- *  version 2 of the License, or (at your option) any later version.
- *
- *  This library is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- *  Library General Public License for more details.
- *
- *  You should have received a copy of the GNU Library General Public License
- *  along with this library; see the file COPYING.LIB.  If not, write to
- *  the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- *  Boston, MA 02110-1301, USA.
- */
+/*
+    SPDX-FileCopyrightText: 2001, 2002 Joseph Wenninger <jowenn@kde.org>
+    SPDX-FileCopyrightText: 2001 Christoph Cullmann <cullmann@kde.org>
+    SPDX-FileCopyrightText: 1999 Jochen Wilhelmy <digisnap@cs.tu-berlin.de>
+
+    SPDX-License-Identifier: LGPL-2.0-or-later
+*/
 
 #ifndef KATE_HIGHLIGHT_H
 #define KATE_HIGHLIGHT_H
@@ -27,29 +14,30 @@
 #include <KSyntaxHighlighting/FoldingRegion>
 #include <KSyntaxHighlighting/Format>
 
-#include "katetextline.h"
 #include "kateextendedattribute.h"
 #include "katesyntaxmanager.h"
-#include "spellcheck/prefixstore.h"
+#include "katetextline.h"
 #include "range.h"
+#include "spellcheck/prefixstore.h"
 
-#include <QVector>
-#include <QList>
 #include <QHash>
+#include <QList>
 #include <QMap>
+#include <QVector>
 
-#include <QRegularExpression>
-#include <QObject>
-#include <QStringList>
-#include <QPointer>
 #include <QDate>
+#include <QObject>
+#include <QPointer>
+#include <QRegularExpression>
+#include <QStringList>
 
 #include <unordered_map>
 
 class KConfig;
 
-namespace KTextEditor {
-    class DocumentPrivate;
+namespace KTextEditor
+{
+class DocumentPrivate;
 }
 
 class KateHighlighting : private KSyntaxHighlighting::AbstractHighlighter
@@ -72,7 +60,7 @@ protected:
      *
      * @see applyFolding(), highlightLine()
      */
-    virtual void applyFormat(int offset, int length, const KSyntaxHighlighting::Format &format) override;
+    void applyFormat(int offset, int length, const KSyntaxHighlighting::Format &format) override;
 
     /**
      * Reimplement this to apply folding to your output. The provided
@@ -89,7 +77,7 @@ protected:
      *
      * @see applyFormat(), highlightLine(), FoldingRegion
      */
-    virtual void applyFolding(int offset, int length, KSyntaxHighlighting::FoldingRegion region) override;
+    void applyFolding(int offset, int length, KSyntaxHighlighting::FoldingRegion region) override;
 
 public:
     /**
@@ -101,19 +89,14 @@ public:
      * @param ctxChanged will be set to reflect if the context changed
      * @param tabWidth tab width for indentation based folding, if wanted, else 0
      */
-    void doHighlight(const Kate::TextLineData *prevLine,
-                     Kate::TextLineData *textLine,
-                     const Kate::TextLineData *nextLine,
-                     bool &ctxChanged,
-                     int tabWidth = 0);
+    void doHighlight(const Kate::TextLineData *prevLine, Kate::TextLineData *textLine, const Kate::TextLineData *nextLine, bool &ctxChanged, int tabWidth = 0);
     /**
      * Saves the attribute definitions to the config file.
      *
      * @param schema The id of the schema group to save
      * @param list QList<KateExtendedAttribute::Ptr> containing the data to be used
      */
-    void setKateExtendedAttributeList(const QString &schema, QVector<KTextEditor::Attribute::Ptr> &list,
-                                      KConfig *cfg = nullptr /*if 0  standard kate config*/, bool writeDefaultsToo = false);
+    void setKateExtendedAttributeList(const QString &schema, QVector<KTextEditor::Attribute::Ptr> &list, KConfig *cfg = nullptr /*if 0  standard kate config*/, bool writeDefaultsToo = false);
 
     const QString &name() const
     {
@@ -155,9 +138,9 @@ public:
     bool isEmptyLine(const Kate::TextLineData *textline) const;
 
     /**
-    * @return true if @p beginAttr and @p endAttr are members of the same
-    * highlight, and there are comment markers of either type in that.
-    */
+     * @return true if @p beginAttr and @p endAttr are members of the same
+     * highlight, and there are comment markers of either type in that.
+     */
     bool canComment(int startAttr, int endAttr) const;
 
     /**
@@ -200,7 +183,7 @@ public:
      * @param cursor cursor position in the given document
      * @return attribute valid at that location, default is 0
      */
-    int attributeForLocation(KTextEditor::DocumentPrivate* doc, const KTextEditor::Cursor& cursor);
+    int attributeForLocation(KTextEditor::DocumentPrivate *doc, const KTextEditor::Cursor &cursor);
 
     /**
      * Get all keywords valid for the given cursor position.
@@ -208,7 +191,7 @@ public:
      * @param cursor cursor position in the given document
      * @return all keywords valid at that location
      */
-    QStringList keywordsForLocation(KTextEditor::DocumentPrivate* doc, const KTextEditor::Cursor& cursor);
+    QStringList keywordsForLocation(KTextEditor::DocumentPrivate *doc, const KTextEditor::Cursor &cursor);
 
     /**
      * Is spellchecking required for the tiven cursor position?
@@ -216,7 +199,7 @@ public:
      * @param cursor cursor position in the given document
      * @return spell checking required?
      */
-    bool spellCheckingRequiredForLocation(KTextEditor::DocumentPrivate* doc, const KTextEditor::Cursor& cursor);
+    bool spellCheckingRequiredForLocation(KTextEditor::DocumentPrivate *doc, const KTextEditor::Cursor &cursor);
 
     /**
      * Get highlighting mode for the given cursor position.
@@ -224,7 +207,7 @@ public:
      * @param cursor cursor position in the given document
      * @return mode valid at that location
      */
-    QString higlightingModeForLocation(KTextEditor::DocumentPrivate* doc, const KTextEditor::Cursor& cursor);
+    QString higlightingModeForLocation(KTextEditor::DocumentPrivate *doc, const KTextEditor::Cursor &cursor);
 
     KTextEditor::DefaultStyle defaultStyleForAttribute(int attr) const;
 
@@ -261,9 +244,10 @@ public:
 private:
     /**
      * create list of attributes from internal formats with properties as defined in syntax file
+     * @param schema The id of the chosen schema
      * @return attributes list with attributes as defined in syntax file
      */
-    QVector<KTextEditor::Attribute::Ptr> attributesForDefinition();
+    QVector<KTextEditor::Attribute::Ptr> attributesForDefinition(const QString &schema);
 
     int sanitizeFormatIndex(int attrib) const;
 
@@ -287,7 +271,7 @@ private:
     bool m_foldingIndentationSensitive = false;
 
     // map schema name to attributes...
-    QHash< QString, QVector<KTextEditor::Attribute::Ptr> > m_attributeArrays;
+    QHash<QString, QVector<KTextEditor::Attribute::Ptr>> m_attributeArrays;
 
     /**
      * This class holds the additional properties for one highlight
@@ -351,4 +335,3 @@ public:
 };
 
 #endif
-
