@@ -1,22 +1,8 @@
-/* This file is part of the KDE and the Kate project
- *
- *   Copyright (C) 2012 Dominik Haumann <dhaumann@kde.org>
- *
- *  This library is free software; you can redistribute it and/or
- *  modify it under the terms of the GNU Library General Public
- *  License as published by the Free Software Foundation; either
- *  version 2 of the License, or (at your option) any later version.
- *
- *  This library is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- *  Library General Public License for more details.
- *
- *  You should have received a copy of the GNU Library General Public License
- *  along with this library; see the file COPYING.LIB.  If not, write to
- *  the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- *  Boston, MA 02110-1301, USA.
- */
+/*
+    SPDX-FileCopyrightText: 2012 Dominik Haumann <dhaumann@kde.org>
+
+    SPDX-License-Identifier: LGPL-2.0-or-later
+*/
 
 #include "katemessagewidget.h"
 
@@ -28,10 +14,10 @@
 #include <kateanimation.h>
 
 #include <QEvent>
-#include <QTimer>
-#include <QVBoxLayout>
-#include <QToolTip>
 #include <QShowEvent>
+#include <QTimer>
+#include <QToolTip>
+#include <QVBoxLayout>
 
 static const int s_defaultAutoHideTime = 6 * 1000;
 
@@ -42,7 +28,7 @@ KateMessageWidget::KateMessageWidget(QWidget *parent, bool applyFadeEffect)
     , m_autoHideTime(-1)
 {
     QVBoxLayout *l = new QVBoxLayout();
-    l->setMargin(0);
+    l->setContentsMargins(0, 0, 0, 0);
 
     m_messageWidget = new KMessageWidget(this);
     m_messageWidget->setCloseButtonVisible(false);
@@ -53,21 +39,20 @@ KateMessageWidget::KateMessageWidget(QWidget *parent, bool applyFadeEffect)
     // tell the widget to always use the minimum size.
     setSizePolicy(QSizePolicy::Preferred, QSizePolicy::Minimum);
 
-    // install event filter so we catch the end of the hide animation
-    m_messageWidget->installEventFilter(this);
-
     // by default, hide widgets
     m_messageWidget->hide();
     hide();
 
     // create animation controller, and connect widgetHidden() to showNextMessage()
     m_animation = new KateAnimation(m_messageWidget, applyFadeEffect ? KateAnimation::FadeEffect : KateAnimation::GrowEffect);
-    connect(m_animation, SIGNAL(widgetHidden()), this, SLOT(showNextMessage()));
+    connect(m_animation, &KateAnimation::widgetHidden,
+            this, &KateMessageWidget::showNextMessage);
 
     // setup autoHide timer details
     m_autoHideTimer->setSingleShot(true);
 
-    connect(m_messageWidget, SIGNAL(linkHovered(QString)), SLOT(linkHovered(QString)));
+    connect(m_messageWidget, &KMessageWidget::linkHovered,
+            this, &KateMessageWidget::linkHovered);
 }
 
 void KateMessageWidget::showNextMessage()
@@ -89,10 +74,10 @@ void KateMessageWidget::showNextMessage()
     m_messageWidget->setIcon(m_currentMessage->icon());
 
     // connect textChanged() and iconChanged(), so it's possible to change this on the fly
-    connect(m_currentMessage, SIGNAL(textChanged(QString)),
-            m_messageWidget, SLOT(setText(QString)), Qt::UniqueConnection);
-    connect(m_currentMessage, SIGNAL(iconChanged(QIcon)),
-            m_messageWidget, SLOT(setIcon(QIcon)), Qt::UniqueConnection);
+    connect(m_currentMessage, &KTextEditor::Message::textChanged,
+            m_messageWidget, &KMessageWidget::setText, Qt::UniqueConnection);
+    connect(m_currentMessage, &KTextEditor::Message::iconChanged,
+            m_messageWidget, &KMessageWidget::setIcon, Qt::UniqueConnection);
 
     // the enums values do not necessarily match, hence translate with switch
     switch (m_currentMessage->messageType()) {
@@ -114,12 +99,14 @@ void KateMessageWidget::showNextMessage()
     }
 
     // remove all actions from the message widget
-    foreach (QAction *a, m_messageWidget->actions()) {
+    const auto messageWidgetActions = m_messageWidget->actions();
+    for (QAction *a : messageWidgetActions) {
         m_messageWidget->removeAction(a);
     }
 
     // add new actions to the message widget
-    foreach (QAction *a, m_currentMessage->actions()) {
+    const auto m_currentMessageActions = m_currentMessage->actions();
+    for (QAction *a : m_currentMessageActions) {
         m_messageWidget->addAction(a);
     }
 
@@ -130,7 +117,8 @@ void KateMessageWidget::showNextMessage()
     m_autoHideTime = m_currentMessage->autoHide();
     m_autoHideTimer->stop();
     if (m_autoHideTime >= 0) {
-        connect(m_autoHideTimer, SIGNAL(timeout()), m_currentMessage, SLOT(deleteLater()), Qt::UniqueConnection);
+        connect(m_autoHideTimer, &QTimer::timeout,
+                m_currentMessage, &QObject::deleteLater, Qt::UniqueConnection);
         if (m_currentMessage->autoHideMode() == KTextEditor::Message::Immediate) {
             m_autoHideTimer->start(m_autoHideTime == 0 ? s_defaultAutoHideTime : m_autoHideTime);
         }
@@ -176,16 +164,15 @@ void KateMessageWidget::setWordWrap(KTextEditor::Message *message)
     // finally enable word wrap, if there is not enough free horizontal space
     const int freeSpace = (parentWidget()->width() - margin) - m_messageWidget->width();
     if (freeSpace < 0) {
-//     qCDebug(LOG_KTE) << "force word wrap to avoid breaking the layout" << freeSpace;
+        //     qCDebug(LOG_KTE) << "force word wrap to avoid breaking the layout" << freeSpace;
         m_messageWidget->setWordWrap(true);
     }
 }
 
-void KateMessageWidget::postMessage(KTextEditor::Message *message,
-                                    QList<QSharedPointer<QAction> > actions)
+void KateMessageWidget::postMessage(KTextEditor::Message *message, QList<QSharedPointer<QAction>> actions)
 {
     Q_ASSERT(!m_messageHash.contains(message));
-    m_messageHash[message] = actions;
+    m_messageHash[message] = std::move(actions);
 
     // insert message sorted after priority
     int i = 0;
@@ -199,16 +186,16 @@ void KateMessageWidget::postMessage(KTextEditor::Message *message,
     m_messageQueue.insert(i, message);
 
     // catch if the message gets deleted
-    connect(message, SIGNAL(closed(KTextEditor::Message*)), SLOT(messageDestroyed(KTextEditor::Message*)));
+    connect(message, &KTextEditor::Message::closed,
+            this, &KateMessageWidget::messageDestroyed);
 
     if (i == 0 && !m_animation->isHideAnimationRunning()) {
         // if message has higher priority than the one currently shown,
         // then hide the current one and then show the new one.
         if (m_currentMessage) {
-
             // autoHide timer may be running for currently shown message, therefore
             // simply disconnect autoHide timer to all timeout() receivers
-            disconnect(m_autoHideTimer, SIGNAL(timeout()), nullptr, nullptr);
+            disconnect(m_autoHideTimer, &QTimer::timeout, nullptr, nullptr);
             m_autoHideTimer->stop();
 
             // if there is a current message, the message queue must contain 2 messages
@@ -216,10 +203,10 @@ void KateMessageWidget::postMessage(KTextEditor::Message *message,
             Q_ASSERT(m_currentMessage == m_messageQueue[1]);
 
             // a bit unnice: disconnect textChanged() and iconChanged() signals of previously visible message
-            disconnect(m_currentMessage, SIGNAL(textChanged(QString)),
-                       m_messageWidget, SLOT(setText(QString)));
-            disconnect(m_currentMessage, SIGNAL(iconChanged(QIcon)),
-                       m_messageWidget, SLOT(setIcon(QIcon)));
+            disconnect(m_currentMessage, &KTextEditor::Message::textChanged,
+                       m_messageWidget, &KMessageWidget::setText);
+            disconnect(m_currentMessage, &KTextEditor::Message::iconChanged,
+                       m_messageWidget, &KMessageWidget::setIcon);
 
             m_currentMessage = nullptr;
             m_animation->hide();
@@ -264,12 +251,12 @@ void KateMessageWidget::messageDestroyed(KTextEditor::Message *message)
 void KateMessageWidget::startAutoHideTimer()
 {
     // message does not want autohide, or timer already running
-    if (!m_currentMessage            // no message, nothing to do
-            || m_autoHideTime < 0          // message does not want auto-hide
-            || m_autoHideTimer->isActive() // auto-hide timer is already active
-            || m_animation->isHideAnimationRunning() // widget is in hide animation phase
-            || m_animation->isShowAnimationRunning() // widget is in show animation phase
-       ) {
+    if (!m_currentMessage                        // no message, nothing to do
+        || m_autoHideTime < 0                    // message does not want auto-hide
+        || m_autoHideTimer->isActive()           // auto-hide timer is already active
+        || m_animation->isHideAnimationRunning() // widget is in hide animation phase
+        || m_animation->isShowAnimationRunning() // widget is in show animation phase
+    ) {
         return;
     }
 
