@@ -1,34 +1,24 @@
-/*  This file is part of the Kate project.
- *
- *  Copyright (C) 2013 Dominik Haumann <dhaumann kde org>
- *
- *  This library is free software; you can redistribute it and/or
- *  modify it under the terms of the GNU Library General Public
- *  License as published by the Free Software Foundation; either
- *  version 2 of the License, or (at your option) any later version.
- *
- *  This library is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- *  Library General Public License for more details.
- *
- *  You should have received a copy of the GNU Library General Public License
- *  along with this library; see the file COPYING.LIB.  If not, write to
- *  the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- *  Boston, MA 02110-1301, USA.
- */
+/*
+    SPDX-FileCopyrightText: 2013-2018 Dominik Haumann <dhaumann@kde.org>
+
+    SPDX-License-Identifier: LGPL-2.0-or-later
+*/
+
 #ifndef KATE_TEXT_ANIMATION_H
 #define KATE_TEXT_ANIMATION_H
 
 #include <QObject>
-#include <QString>
 #include <QRectF>
+#include <QString>
 
+#include <ktexteditor/attribute.h>
 #include <ktexteditor/cursor.h>
 #include <ktexteditor/range.h>
-#include <ktexteditor/attribute.h>
 
-namespace KTextEditor { class DocumentPrivate; }
+namespace KTextEditor
+{
+class DocumentPrivate;
+}
 class KateViewInternal;
 class QTimeLine;
 class QPainter;
@@ -68,4 +58,3 @@ private:
 };
 
 #endif // KATE_TEXT_ANIMATION_H
-
