@@ -1,49 +1,33 @@
-/*  This file is part of the KDE libraries and the Kate part.
- *
- *  Copyright (C) 2008-2011 Erlend Hamberg <ehamberg@gmail.com>
- *  Copyright (C) 2011 Svyatoslav Kuzmich <svatoslav1@gmail.com>
- *  Copyright (C) 2012 - 2013 Simon St James <kdedevel@etotheipiplusone.com>
- *
- *  This library is free software; you can redistribute it and/or
- *  modify it under the terms of the GNU Library General Public
- *  License as published by the Free Software Foundation; either
- *  version 2 of the License, or (at your option) any later version.
- *
- *  This library is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- *  Library General Public License for more details.
- *
- *  You should have received a copy of the GNU Library General Public License
- *  along with this library; see the file COPYING.LIB.  If not, write to
- *  the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- *  Boston, MA 02110-1301, USA.
- */
+/*
+    SPDX-FileCopyrightText: 2008-2011 Erlend Hamberg <ehamberg@gmail.com>
+    SPDX-FileCopyrightText: 2011 Svyatoslav Kuzmich <svatoslav1@gmail.com>
+    SPDX-FileCopyrightText: 2012-2013 Simon St James <kdedevel@etotheipiplusone.com>
 
-#include <vimode/modes/insertvimode.h>
-#include <vimode/inputmodemanager.h>
+    SPDX-License-Identifier: LGPL-2.0-or-later
+*/
+
+#include "katecompletiontree.h"
+#include "katecompletionwidget.h"
+#include "kateconfig.h"
+#include "kateglobal.h"
+#include "katepartdebug.h"
 #include "kateview.h"
 #include "kateviewinternal.h"
-#include "kateconfig.h"
-#include "katecompletionwidget.h"
-#include "katecompletiontree.h"
-#include "kateglobal.h"
-#include <vimode/keyparser.h>
-#include "katepartdebug.h"
 #include "kateviinputmode.h"
 #include <vimode/completionrecorder.h>
 #include <vimode/completionreplayer.h>
-#include <vimode/marks.h>
-#include <vimode/macrorecorder.h>
+#include <vimode/inputmodemanager.h>
+#include <vimode/keyparser.h>
 #include <vimode/lastchangerecorder.h>
+#include <vimode/macrorecorder.h>
+#include <vimode/marks.h>
+#include <vimode/modes/insertvimode.h>
 
 #include <KLocalizedString>
 
 using namespace KateVi;
 
-InsertViMode::InsertViMode(InputModeManager *viInputModeManager,
-                       KTextEditor::ViewPrivate *view,
-                       KateViewInternal *viewInternal)
+InsertViMode::InsertViMode(InputModeManager *viInputModeManager, KTextEditor::ViewPrivate *view, KateViewInternal *viewInternal)
     : ModeBase()
 {
     m_view = view;
@@ -58,8 +42,7 @@ InsertViMode::InsertViMode(InputModeManager *viInputModeManager,
 
     m_isExecutingCompletion = false;
 
-    connect(doc(), SIGNAL(textInserted(KTextEditor::Document*,KTextEditor::Range)),
-            this, SLOT(textInserted(KTextEditor::Document*,KTextEditor::Range)));
+    connect(doc(), SIGNAL(textInserted(KTextEditor::Document *, KTextEditor::Range)), this, SLOT(textInserted(KTextEditor::Document *, KTextEditor::Range)));
 }
 
 InsertViMode::~InsertViMode()
@@ -191,7 +174,7 @@ bool InsertViMode::commandUnindent()
 
 bool InsertViMode::commandToFirstCharacterInFile()
 {
-    KTextEditor::Cursor c(0,0);
+    KTextEditor::Cursor c(0, 0);
     updateCursor(c);
     return true;
 }
@@ -278,9 +261,9 @@ bool InsertViMode::commandInsertContentOfRegister()
     }
 
     if (m == LineWise) {
-        textToInsert.chop(1);   // remove the last \n
-        c.setColumn(doc()->lineLength(c.line()));     // paste after the current line and ...
-        textToInsert.prepend(QLatin1Char('\n'));   // ... prepend a \n, so the text starts on a new line
+        textToInsert.chop(1);                     // remove the last \n
+        c.setColumn(doc()->lineLength(c.line())); // paste after the current line and ...
+        textToInsert.prepend(QLatin1Char('\n'));  // ... prepend a \n, so the text starts on a new line
 
         cAfter.setLine(cAfter.line() + 1);
         cAfter.setColumn(0);
@@ -374,9 +357,7 @@ bool InsertViMode::handleKeypress(const QKeyEvent *e)
                     m_isExecutingCompletion = false;
                     return true;
                 }
-#if QT_VERSION >= QT_VERSION_CHECK(5,8,0)
-        Q_FALLTHROUGH();
-#endif
+                Q_FALLTHROUGH();
             default:
                 return false;
             }
@@ -459,19 +440,17 @@ bool InsertViMode::handleKeypress(const QKeyEvent *e)
         return false;
     } else if (m_waitingRegister) {
         // ignore modifier keys alone
-        if (e->key() == Qt::Key_Shift || e->key() == Qt::Key_Control ||
-                e->key() == Qt::Key_Alt || e->key() == Qt::Key_Meta) {
+        if (e->key() == Qt::Key_Shift || e->key() == Qt::Key_Control || e->key() == Qt::Key_Alt || e->key() == Qt::Key_Meta) {
             return false;
         }
 
-        QChar key =  KeyParser::self()->KeyEventToQChar(*e);
+        QChar key = KeyParser::self()->KeyEventToQChar(*e);
         key = key.toLower();
         m_waitingRegister = false;
 
         // is it register ?
         // TODO: add registers such as '/'. See :h <c-r>
-        if ((key >= QLatin1Char('0') && key <= QLatin1Char('9')) || (key >= QLatin1Char('a') && key <= QLatin1Char('z')) ||
-                key == QLatin1Char('_') || key == QLatin1Char('+') || key == QLatin1Char('*') || key == QLatin1Char('"')) {
+        if ((key >= QLatin1Char('0') && key <= QLatin1Char('9')) || (key >= QLatin1Char('a') && key <= QLatin1Char('z')) || key == QLatin1Char('_') || key == QLatin1Char('-') || key == QLatin1Char('+') || key == QLatin1Char('*') || key == QLatin1Char('"')) {
             m_register = key;
         } else {
             return false;
@@ -489,7 +468,7 @@ void InsertViMode::leaveInsertMode(bool force)
 {
     m_view->abortCompletion();
     if (!force) {
-        if (m_blockInsert != None) {   // block append/prepend
+        if (m_blockInsert != None) { // block append/prepend
 
             // make sure cursor haven't been moved
             if (m_blockRange.startLine == m_view->cursorPosition().line()) {
